###################################################
### chunk number 1: preliminaries
###################################################
#line 49 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
set.seed(1071)
library(vcd)
data(Titanic)
data(HairEyeColor)
data(PreSex)
data(Arthritis)
art <- xtabs(~Treatment + Improved, data = Arthritis)


###################################################
### chunk number 2: Arthritis
###################################################
#line 203 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(art, gp = shading_max, split_vertical = TRUE)


###################################################
### chunk number 3: UCBAdmissions
###################################################
#line 214 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
cotabplot(UCBAdmissions, panel = cotab_coindep, shade = TRUE, legend = FALSE,
          type = "assoc")


###################################################
### chunk number 4: PreSex
###################################################
#line 226 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
presextest <- coindep_test(PreSex, margin = c(1,4),
                           indepfun = function(x) sum(x^2), n = 5000)
mosaic(PreSex, condvars = c(1, 4), shade = TRUE,
       gp_args = list(p.value = presextest$p.value))


###################################################
### chunk number 5: Titanic
###################################################
#line 240 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
doubledecker(Survived ~ ., data = Titanic, labeling_args =
             list(set_varnames = c(Sex = "Gender")))


###################################################
### chunk number 6: vcdlayout
###################################################
#line 405 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
    pushViewport(vcd:::vcdViewport(legend = T, mar =4))
    seekViewport("main")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("main", gp = gpar(fontsize = 20))
    seekViewport("sub")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("sub", gp = gpar(fontsize = 20))
    seekViewport("plot")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("plot", gp = gpar(fontsize = 20))
    seekViewport("legend")
    grid.text("legend", rot = 90, gp = gpar(fontsize = 20))
    grid.rect(gp = gpar(lwd = 3))
    seekViewport("legend_sub")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[F]", gp = gpar(fontsize = 20))
    seekViewport("legend_top")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[E]", gp = gpar(fontsize = 20))
    seekViewport("margin_top")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("margin_top", gp = gpar(fontsize = 20))
    seekViewport("margin_bottom")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("margin_bottom", gp = gpar(fontsize = 20))
    seekViewport("margin_right")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("margin_right", rot = 90, gp = gpar(fontsize = 20))
    seekViewport("margin_left")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("margin_left", rot = 90, gp = gpar(fontsize = 20))
    seekViewport("corner_top_left")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[A]", gp = gpar(fontsize = 20))
    seekViewport("corner_top_right")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[B]", gp = gpar(fontsize = 20))
    seekViewport("corner_bottom_left")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[C]", gp = gpar(fontsize = 20))
    seekViewport("corner_bottom_right")
    grid.rect(gp = gpar(lwd = 3))
    grid.text("[D]", gp = gpar(fontsize = 20))


###################################################
### chunk number 7: structable
###################################################
#line 468 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
(HEC <- structable(Eye ~ Sex + Hair, data = HairEyeColor))


###################################################
### chunk number 8: Observed
###################################################
#line 481 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(HEC)


###################################################
### chunk number 9: Observed2
###################################################
#line 487 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ Sex + Eye + Hair, data = HairEyeColor)


###################################################
### chunk number 10: Observedfig
###################################################
#line 494 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 481 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#494#"
mosaic(HEC)
#line 495 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 11: Expected
###################################################
#line 516 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(HEC, type = "expected")


###################################################
### chunk number 12: Expectedfig
###################################################
#line 522 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 516 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#522#"
mosaic(HEC, type = "expected")
#line 523 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 13: sieve
###################################################
#line 535 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
sieve(~ Sex + Eye + Hair, data = HEC, spacing = spacing_dimequal(c(2,0,0)))


###################################################
### chunk number 14: sievefig
###################################################
#line 541 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 535 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#541#"
sieve(~ Sex + Eye + Hair, data = HEC, spacing = spacing_dimequal(c(2,0,0)))
#line 542 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 15: Residuals
###################################################
#line 558 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
assoc(HEC, compress = FALSE)


###################################################
### chunk number 16: Residualsfig
###################################################
#line 564 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 558 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#564#"
assoc(HEC, compress = FALSE)
#line 565 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 17: 
###################################################
#line 580 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
options(width=60)


###################################################
### chunk number 18: split1
###################################################
#line 584 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(HEC, split_vertical = c(TRUE, FALSE, TRUE),
labeling_args = list(abbreviate = c(Eye = 3)))


###################################################
### chunk number 19: 
###################################################
#line 589 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
options(width=70)


###################################################
### chunk number 20: splitfig
###################################################
#line 595 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 584 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#595#"
mosaic(HEC, split_vertical = c(TRUE, FALSE, TRUE),
labeling_args = list(abbreviate = c(Eye = 3)))
#line 596 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 21: split2
###################################################
#line 610 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(HEC, direction = c("v","h","v"))


###################################################
### chunk number 22: doubledecker1
###################################################
#line 628 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
doubledecker(Titanic)


###################################################
### chunk number 23: doubledecker2
###################################################
#line 634 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
doubledecker(Survived ~ Class + Sex + Age, data = Titanic)


###################################################
### chunk number 24: 
###################################################
#line 653 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
options(width=75)


###################################################
### chunk number 25: subsetting
###################################################
#line 657 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
(STD <- structable(~ Sex + Class + Age, data = Titanic[,,2:1,]))
STD["Male",]
STD["Male", c("1st","2nd","3rd")]


###################################################
### chunk number 26: 
###################################################
#line 663 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
options(width=70)


###################################################
### chunk number 27: conditioning
###################################################
#line 674 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
STD[["Male",]]
STD[[c("Male", "Adult"),]]
STD[["Male","1st"]]


###################################################
### chunk number 28: Variables1
###################################################
#line 687 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2)))


###################################################
### chunk number 29: Variables2
###################################################
#line 691 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout.pos.col = 1))
mosaic(STD[["Male"]], margins = c(left = 2.5, top = 2.5, 0), sub = "Male", newpage = FALSE)
popViewport()


###################################################
### chunk number 30: Variables3
###################################################
#line 697 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout.pos.col = 2))
mosaic(STD[["Female"]], margins = c(top = 2.5, 0), sub = "Female", newpage = FALSE)
popViewport(2)


###################################################
### chunk number 31: Variablesfig
###################################################
#line 706 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 687 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#706#"
pushViewport(viewport(layout = grid.layout(ncol = 2)))
#line 707 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 691 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#707#"
pushViewport(viewport(layout.pos.col = 1))
mosaic(STD[["Male"]], margins = c(left = 2.5, top = 2.5, 0), sub = "Male", newpage = FALSE)
popViewport()
#line 708 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 697 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#708#"
pushViewport(viewport(layout.pos.col = 2))
mosaic(STD[["Female"]], margins = c(top = 2.5, 0), sub = "Female", newpage = FALSE)
popViewport(2)
#line 709 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 32: cotabplot
###################################################
#line 732 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
cotabplot(~ Class + Age | Sex, data = STD, split_vertical = TRUE)


###################################################
### chunk number 33: cotabplotfig
###################################################
#line 739 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 732 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#739#"
cotabplot(~ Class + Age | Sex, data = STD, split_vertical = TRUE)
#line 740 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 34: Conditioning1
###################################################
#line 764 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(STD, condvars = "Sex", split_vertical = c(TRUE, TRUE, FALSE))


###################################################
### chunk number 35: Conditioning2
###################################################
#line 767 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ Class + Age | Sex, data = STD, split_vertical = c(TRUE, TRUE, FALSE))


###################################################
### chunk number 36: Conditioningfig
###################################################
#line 774 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 767 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#774#"
mosaic(~ Class + Age | Sex, data = STD, split_vertical = c(TRUE, TRUE, FALSE))
#line 775 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 37: pairs
###################################################
#line 816 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pairs(STD, highlighting = 2, diag_panel = pairs_diagonal_mosaic,
      diag_panel_args = list(fill = grey.colors))


###################################################
### chunk number 38: pairsfig
###################################################
#line 826 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 816 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#826#"
pairs(STD, highlighting = 2, diag_panel = pairs_diagonal_mosaic,
      diag_panel_args = list(fill = grey.colors))
#line 827 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 39: viewportnames
###################################################
#line 883 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ Hair + Eye, data = HEC, pop = FALSE)

seekViewport("cell:Hair=Blond")
grid.rect(gp = gpar(col = "red", lwd = 4))

seekViewport("cell:Hair=Blond,Eye=Blue")
grid.circle(r = 0.2, gp = gpar(fill = "cyan"))


###################################################
### chunk number 40: viewportnamesfig
###################################################
#line 900 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 883 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#900#"
mosaic(~ Hair + Eye, data = HEC, pop = FALSE)

seekViewport("cell:Hair=Blond")
grid.rect(gp = gpar(col = "red", lwd = 4))

seekViewport("cell:Hair=Blond,Eye=Blue")
grid.circle(r = 0.2, gp = gpar(fill = "cyan"))
#line 901 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 41: changeplot
###################################################
#line 913 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
assoc(Eye ~ Hair, data = HEC, pop = FALSE)
getNames()[1:6]
grid.edit("rect:Hair=Blond,Eye=Blue", gp = gpar(fill = "red"))


###################################################
### chunk number 42: changeplotfig
###################################################
#line 922 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
x <- tab <- margin.table(HairEyeColor, 1:2)
x[] <- "light gray"
x["Blond","Blue"] <- "Red"
assoc(tab, gp = gpar(fill = x))


###################################################
### chunk number 43: ucb
###################################################
#line 1001 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
(ucb <- margin.table(UCBAdmissions, 1:2))

(fill_colors <- matrix(c("dark cyan","gray","gray","dark magenta"), ncol = 2))

mosaic(ucb, gp = gpar(fill = fill_colors, col = 0))


###################################################
### chunk number 44: ucbfig
###################################################
#line 1011 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 1001 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#1011#"
(ucb <- margin.table(UCBAdmissions, 1:2))

(fill_colors <- matrix(c("dark cyan","gray","gray","dark magenta"), ncol = 2))

mosaic(ucb, gp = gpar(fill = fill_colors, col = 0))
#line 1012 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 45: recycling
###################################################
#line 1033 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, gp = gpar(fill = c("gray","dark magenta")),
                spacing = spacing_highlighting,
                labeling_args = list(abbreviate = c(Age = 3), rep = c(Survived = FALSE))
      )


###################################################
### chunk number 46: recyclingfig
###################################################
#line 1046 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 1033 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#1046#"
mosaic(Titanic, gp = gpar(fill = c("gray","dark magenta")),
                spacing = spacing_highlighting,
                labeling_args = list(abbreviate = c(Age = 3), rep = c(Survived = FALSE))
      )
#line 1047 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 47: shading1
###################################################
#line 1094 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
expected <- independence_table(ucb)
(x <- (ucb - expected)  / sqrt(expected))

(shading1_obj <- ifelse(x > 0, "royalblue4", "mediumorchid4"))

mosaic(ucb, gp = gpar(fill = shading1_obj))


###################################################
### chunk number 48: shading1fig
###################################################
#line 1105 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 1094 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#1105#"
expected <- independence_table(ucb)
(x <- (ucb - expected)  / sqrt(expected))

(shading1_obj <- ifelse(x > 0, "royalblue4", "mediumorchid4"))

mosaic(ucb, gp = gpar(fill = shading1_obj))
#line 1106 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 49: shading2
###################################################
#line 1119 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
shading2_fun <- function(x) gpar(fill = ifelse(x > 0, "royalblue4", "mediumorchid4"))


###################################################
### chunk number 50: shading3
###################################################
#line 1127 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(ucb, gp = shading2_fun)


###################################################
### chunk number 51: shading3
###################################################
#line 1160 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
shading3a_fun <- function(col = c("royalblue4", "mediumorchid4")) {
  col <- rep(col, length.out = 2)
  function(x) gpar(fill = ifelse(x > 0, col[1], col[2]))
}


###################################################
### chunk number 52: shading4
###################################################
#line 1171 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(ucb, gp = shading3a_fun(c("royalblue4","mediumorchid4")))


###################################################
### chunk number 53: shading4
###################################################
#line 1200 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
shading3b_fun <- function(observed = NULL, residuals = NULL, expected = NULL,
    df = NULL, col = c("royalblue4", "mediumorchid4")) {
  col <- rep(col, length.out = 2)
  function(x) gpar(fill = ifelse(x > 0, col[1], col[2]))
}
class(shading3b_fun) <- "grapcon_generator"


###################################################
### chunk number 54: shading5
###################################################
#line 1220 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(ucb, gp = shading3b_fun, gp_args = list(col = c("red","blue")))


###################################################
### chunk number 55: haireye1
###################################################
#line 1268 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
haireye <- margin.table(HairEyeColor, 1:2)
mosaic(haireye, gp = shading_hsv)


###################################################
### chunk number 56: haireye2
###################################################
#line 1279 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, gp = shading_hcl)


###################################################
### chunk number 57: haireye3
###################################################
#line 1282 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, gp = shading_hcl, gp_args = list(h = c(130, 43), c = 100, l = c(90, 70)))


###################################################
### chunk number 58: haireyefig1
###################################################
#line 1294 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, gp = shading_hsv, margin = c(bottom = 1), keep_aspect_ratio = FALSE)


###################################################
### chunk number 59: haireyefig2
###################################################
#line 1297 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, gp = shading_hcl, margin = c(bottom = 1), keep_aspect_ratio = FALSE)


###################################################
### chunk number 60: haireyefig3
###################################################
#line 1300 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, gp = shading_hcl, margin = c(bottom = 1), gp_args = list(h = c(130, 43), c = 100, l = c(90, 70)), keep_aspect_ratio = FALSE)


###################################################
### chunk number 61: interpolate
###################################################
#line 1325 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, shade = TRUE, gp_args = list(interpolate = 1:4))


###################################################
### chunk number 62: continuous1
###################################################
#line 1341 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
ipol <- function(x) pmin(x/4, 1)


###################################################
### chunk number 63: continuous2
###################################################
#line 1351 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(haireye, shade = TRUE, gp_args = list(interpolate = ipol),
labeling_args = list(abbreviate = c(Sex = TRUE)))


###################################################
### chunk number 64: interpolatefig
###################################################
#line 1359 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2)))
pushViewport(viewport(layout.pos.col = 1))
mosaic(haireye, gp_args = list(interpolate = 1:4), margin = c(right = 1), keep_aspect_ratio= FALSE,newpage = FALSE,legend_width=5.5,shade = TRUE)
popViewport(1)
pushViewport(viewport(layout.pos.col = 2))
mosaic(haireye, gp_args = list(interpolate = ipol), margin = c(left=3,right = 1), keep_aspect_ratio = FALSE, newpage = FALSE, shade = TRUE)
popViewport(2)


###################################################
### chunk number 65: bundesliga
###################################################
#line 1398 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
BL <- xtabs(~ HomeGoals + AwayGoals, data = Bundesliga, subset = Year == 1995)
mosaic(BL, shade = TRUE)


###################################################
### chunk number 66: friendly
###################################################
#line 1414 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(BL, gp = shading_Friendly, legend = legend_fixed, zero_size = 0)


###################################################
### chunk number 67: bundesligafig
###################################################
#line 1421 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2)))
pushViewport(viewport(layout.pos.col = 1))
mosaic(BL, margin = c(right = 1), keep_aspect_ratio= FALSE, newpage = FALSE,
       legend_width=5.5, shade = TRUE)
popViewport(1)
pushViewport(viewport(layout.pos.col = 2))
mosaic(BL, gp = shading_Friendly, legend = legend_fixed, zero_size = 0,
       margin = c(right = 1), keep_aspect_ratio= FALSE, newpage = FALSE,
       legend_width=5.5)
popViewport(2)


###################################################
### chunk number 68: arthritis
###################################################
#line 1673 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
set.seed(4711)
mosaic(~ Treatment + Improved, data = Arthritis, subset = Sex == "Female",
       gp = shading_max)


###################################################
### chunk number 69: arthritisfig
###################################################
#line 1681 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 1673 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#1681#"
set.seed(4711)
mosaic(~ Treatment + Improved, data = Arthritis, subset = Sex == "Female",
       gp = shading_max)
#line 1682 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 70: default
###################################################
#line 1735 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic)


###################################################
### chunk number 71: clipping
###################################################
#line 1756 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(clip = c(Survived = TRUE, Age = TRUE)))


###################################################
### chunk number 72: abbreviating
###################################################
#line 1783 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = TRUE, Age = 3)))


###################################################
### chunk number 73: rotate
###################################################
#line 1803 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(rot_labels = c(bottom = 90, right = 0),
offset_varnames = c(right = 1), offset_labels = c(right = 0.3)),
margins = c(right = 4, bottom = 3))


###################################################
### chunk number 74: repeat
###################################################
#line 1822 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(rep = c(Survived = FALSE, Age = FALSE)))


###################################################
### chunk number 75: label1fig
###################################################
#line 1829 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2,nrow=3)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
mosaic(Titanic, newpage = FALSE, keep = TRUE, margin = c(right = 3),
       gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
mosaic(Titanic, labeling_args = list(clip = c(Survived = TRUE, Age = TRUE)),
       newpage = FALSE, keep = TRUE, margin = c(left = 3), gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = TRUE, Age = 2)),
       newpage = FALSE, keep = TRUE, margin = c(right = 3), gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 2))
mosaic(Titanic, labeling_args = list(rep = c(Survived = FALSE, Age = FALSE)),
       newpage = FALSE, keep = TRUE, margin = c(left = 3), gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 1:2, layout.pos.row = 3))
pushViewport(viewport(width = 0.55))
mosaic(Titanic, labeling_args = list(rot_labels = c(bottom = 90, right = 0),
                  offset_varnames = c(right = 1), offset_labels = c(right = 0.3)),
       margins = c(right = 4, bottom = 3), newpage = FALSE, keep = FALSE, gp_labels = gpar(fontsize = 10))
popViewport(3)


###################################################
### chunk number 76: left
###################################################
#line 1870 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(pos_varnames = "left", pos_labels = "left",
       just_labels = "left", rep = FALSE))


###################################################
### chunk number 77: left2
###################################################
#line 1889 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling = labeling_left)


###################################################
### chunk number 78: margins
###################################################
#line 1897 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE, abbreviate = c(Survived = 1, Age = 3)))


###################################################
### chunk number 79: boxes
###################################################
#line 1915 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE,
       boxes = TRUE, clip = TRUE))


###################################################
### chunk number 80: boxes2
###################################################
#line 1936 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling = labeling_cboxed)


###################################################
### chunk number 81: labbl
###################################################
#line 1945 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(tl_labels = TRUE, boxes = TRUE,
       clip = c(Survived = FALSE, Age = FALSE, TRUE), abbreviate = c(Age = 4),
       labbl_varnames = TRUE), margins = c(left = 4, right = 1, 3))


###################################################
### chunk number 82: labbl2
###################################################
#line 1968 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling = labeling_lboxed, margins = c(right = 4, left = 1, 3))


###################################################
### chunk number 83: label2fig
###################################################
#line 1977 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2, nrow = 2)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
mosaic(Titanic, labeling_args = list(pos_varnames = "left", pos_labels = "left",
       just_labels = "left", rep = FALSE), newpage = FALSE, keep = TRUE,
       gp_labels = gpar(fontsize = 12))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE,
                  abbreviate = c(Survived = 1, Age = 3)), newpage = FALSE, keep = TRUE,
       margins = c(left = 4, right = 1, 3), gp_labels = gpar(fontsize = 12))
popViewport()
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
mosaic(Titanic, labeling_args = list(tl_labels = FALSE, tl_varnames = TRUE,
       boxes = TRUE, clip = TRUE), newpage = FALSE, keep = TRUE,
       gp_labels = gpar(fontsize = 12))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 2))
mosaic(Titanic, labeling_args = list(tl_labels = TRUE, boxes = TRUE,
       clip = c(Survived = FALSE, Age = FALSE, TRUE),
       labbl_varnames = TRUE, abbreviate = c(Age = 4)),
       margins = c(left = 4, right = 1, 3),
       newpage = FALSE, keep = TRUE, gp_labels = gpar(fontsize = 12))
popViewport(2)


###################################################
### chunk number 84: cell
###################################################
#line 2020 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ MaritalStatus + Gender, data = PreSex, labeling = labeling_cells)


###################################################
### chunk number 85: cell2
###################################################
#line 2038 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ PremaritalSex + ExtramaritalSex, data = PreSex,
labeling = labeling_cells(abbreviate_labels = TRUE, abbreviate_varnames = TRUE, clip = FALSE))


###################################################
### chunk number 86: conditional
###################################################
#line 2057 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(~ PremaritalSex + ExtramaritalSex | MaritalStatus + Gender, data = PreSex, labeling = labeling_conditional(abbreviate_varnames = TRUE, abbreviate_labels = TRUE, clip = FALSE, gp_text = gpar(col = "red")))


###################################################
### chunk number 87: text
###################################################
#line 2080 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = 1, Age = 4)), pop = FALSE)

tab <- ifelse(Titanic < 6, NA, Titanic)
labeling_cells(text = tab, clip = FALSE)(Titanic)


###################################################
### chunk number 88: label3fig
###################################################
#line 2102 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
grid.newpage()
pushViewport(viewport(layout = grid.layout(ncol = 2, nrow = 2)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
mosaic(~ MaritalStatus + Gender, data = PreSex, labeling = labeling_cells, newpage = FALSE, keep = TRUE, gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
mosaic(~ PremaritalSex + ExtramaritalSex, data = PreSex,
       labeling = labeling_cells(abbreviate_labels = TRUE, abbreviate_varnames = TRUE,
         clip = FALSE), newpage = FALSE, keep = TRUE, gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
mosaic(~ PremaritalSex + ExtramaritalSex | MaritalStatus + Gender, data = PreSex,
       labeling = labeling_conditional(abbreviate_varnames = TRUE,
         abbreviate_labels = TRUE, clip = FALSE, gp_text = gpar(col = "red")),
       newpage = FALSE, keep = TRUE, gp_labels = gpar(fontsize = 10))
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 2))
mosaic(Titanic, labeling_args = list(abbreviate = c(Survived = 1, Age = 3)),
       pop = FALSE, newpage = FALSE, keep = TRUE, gp_labels = gpar(fontsize = 10))
tab <- ifelse(Titanic < 6, NA, Titanic)
labeling_cells(text = tab, clip = FALSE)(Titanic)


###################################################
### chunk number 89: list
###################################################
#line 2143 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling = labeling_list, margins = c(bottom = 5))


###################################################
### chunk number 90: listfig
###################################################
#line 2150 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Titanic, labeling = labeling_list, margins = c(bottom = 5), keep = TRUE)


###################################################
### chunk number 91: artspine
###################################################
#line 2185 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
(art <- structable(~Treatment + Improved, data = Arthritis, split_vertical = TRUE))
(my_spacing <- list(unit(0.5, "lines"), unit(c(0, 0), "lines")))
my_colors <- c("lightgray", "lightgray", "black")
mosaic(art, spacing = my_spacing, gp = gpar(fill = my_colors, col = my_colors))


###################################################
### chunk number 92: artspinefig
###################################################
#line 2194 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 2185 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#2194#"
(art <- structable(~Treatment + Improved, data = Arthritis, split_vertical = TRUE))
(my_spacing <- list(unit(0.5, "lines"), unit(c(0, 0), "lines")))
my_colors <- c("lightgray", "lightgray", "black")
mosaic(art, spacing = my_spacing, gp = gpar(fill = my_colors, col = my_colors))
#line 2195 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 93: artspine
###################################################
#line 2207 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(Improved ~ Treatment, data = Arthritis, split_vertical = TRUE)


###################################################
### chunk number 94: space1
###################################################
#line 2217 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(art, spacing = spacing_equal(unit(2, "lines")))


###################################################
### chunk number 95: space2
###################################################
#line 2226 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(art, spacing = spacing_dimequal(unit(1:2, "lines")))


###################################################
### chunk number 96: space3
###################################################
#line 2235 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(art, spacing = spacing_increase(start = unit(0.5, "lines"), rate = 1.5))


###################################################
### chunk number 97: spine4
###################################################
#line 2244 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(art, spacing = spacing_highlighting, gp = my_colors)


###################################################
### chunk number 98: spacingfig
###################################################
#line 2263 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
pushViewport(viewport(layout = grid.layout(ncol = 2, nrow = 2)))
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 1))
mosaic(art, spacing = spacing_equal(unit(2, "lines")), keep = TRUE, newpage = FALSE)
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 1))
mosaic(art, spacing = spacing_dimequal(unit(c(0.5, 2), "lines")), keep = TRUE, newpage = FALSE)
popViewport()
pushViewport(viewport(layout.pos.col = 1, layout.pos.row = 2))
mosaic(art, spacing = spacing_increase(start = unit(0.3, "lines"), rate = 2.5), keep = TRUE, newpage = FALSE)
popViewport()
pushViewport(viewport(layout.pos.col = 2, layout.pos.row = 2))
mosaic(art, spacing = spacing_highlighting, keep = TRUE, newpage = FALSE)
popViewport(2)


###################################################
### chunk number 99: oc1
###################################################
#line 2305 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
tab <- xtabs(Freq ~ stage + operation + xray + survival, data = OvaryCancer)


###################################################
### chunk number 100: oc2
###################################################
#line 2311 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
structable(survival ~ ., data = tab)


###################################################
### chunk number 101: oc3
###################################################
#line 2317 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
dpa <- list(var_offset = 1.2, rot = -30, just_leveltext= "left")
pairs(tab, diag_panel_args = dpa)


###################################################
### chunk number 102: ocpairs
###################################################
#line 2324 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 2317 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#2324#"
dpa <- list(var_offset = 1.2, rot = -30, just_leveltext= "left")
pairs(tab, diag_panel_args = dpa)
#line 2325 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 103: oc4
###################################################
#line 2355 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
doubledecker(survival ~ stage + operation + xray, data = tab)


###################################################
### chunk number 104: ocdoubledecker
###################################################
#line 2361 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 2355 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#2361#"
doubledecker(survival ~ stage + operation + xray, data = tab)
#line 2362 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 105: oc6
###################################################
#line 2393 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
split <- c(TRUE, TRUE, TRUE, FALSE)
mosaic(tab, expected = ~ survival + operation * xray * stage, split_vertical = split)


###################################################
### chunk number 106: ocmosaicnull
###################################################
#line 2400 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 2393 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#2400#"
split <- c(TRUE, TRUE, TRUE, FALSE)
mosaic(tab, expected = ~ survival + operation * xray * stage, split_vertical = split)
#line 2401 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


###################################################
### chunk number 107: oc7
###################################################
#line 2418 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
mosaic(tab, expected = ~ (survival + operation * xray) * stage, split_vertical = split)


###################################################
### chunk number 108: ocmosaicstage
###################################################
#line 2424 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"
#line 2418 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw#from line#2424#"
mosaic(tab, expected = ~ (survival + operation * xray) * stage, split_vertical = split)
#line 2425 "/build/buildd/r-cran-vcd-1.2-9/inst/doc/strucplot.Rnw"


